# labeva

<!-- badges-begin -->
![Package version][package version badge]
![Python version][python version badge]
[![License: GNU General Public License v3 or later (GPLv3+)][license badge]][license gplv3]

[![Black codestyle][black badge]][black project]
[![Conventional commits][conventional badge]][conventional commits]
[![pre-commit enabled][pre-commit badge]][pre-commit project]

[license badge]: https://badgen.net/static/license/GPLv3+/blue
[license gplv3]: https://www.gnu.org/licenses/gpl-3.0.en.html

[black badge]: https://img.shields.io/badge/code%20style-black-000000.svg
[black project]: https://github.com/psf/black

[pre-commit badge]: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
[pre-commit project]: https://pre-commit.com/

[package version badge]: https://badgen.net/pypi/v/labeva
[python version badge]: https://badgen.net/pypi/python/labeva

[status badge]: https://badgen.net/badge/status/alpha/red

[conventional badge]: https://img.shields.io/badge/Conventional%20Commits-1.0.0-%23FE5196?logo=conventionalcommits&logoColor=white
[conventional commits]: https://www.conventionalcommits.org/en/v1.0.0/

<!-- badges-end -->


Tools for analysing, fitting and plotting data .
